import { getParsedType, hasKeys, INVALID, isOneOf, OK, ParsedType } from "@postgresql-typed/util";
import { PGTPBase } from "../../util/PGTPBase.js";
import { PGTPConstructorBase } from "../../util/PGTPConstructorBase.js";
import { throwPGTPError } from "../../util/throwPGTPError.js";
class CharacterVaryingConstructorClass extends PGTPConstructorBase {
    constructor(_n = Number.POSITIVE_INFINITY) {
        super();
        this._n = _n;
        const allowedTypes = [ParsedType.number, ParsedType.infinity], parsedType = getParsedType(_n);
        if (!isOneOf(allowedTypes, parsedType)) {
            throwPGTPError({
                code: "invalid_type",
                expected: allowedTypes,
                received: parsedType,
            });
        }
        if (_n < 1) {
            throwPGTPError({
                code: "too_small",
                type: "number",
                minimum: 1,
                inclusive: true,
            });
        }
        if (_n > 10485760 && _n !== Number.POSITIVE_INFINITY) {
            throwPGTPError({
                code: "too_big",
                type: "number",
                maximum: 10485760,
                inclusive: true,
            });
        }
        //If limit is not a whole number
        if (_n % 1 !== 0 && _n !== Number.POSITIVE_INFINITY) {
            throwPGTPError({
                code: "not_whole",
            });
        }
    }
    _parse(context) {
        if (context.data.length !== 1) {
            this.setIssueForContext(context, context.data.length > 1
                ? {
                    code: "too_big",
                    type: "arguments",
                    maximum: 1,
                    exact: true,
                }
                : {
                    code: "too_small",
                    type: "arguments",
                    minimum: 1,
                    exact: true,
                });
            return INVALID;
        }
        const [argument] = context.data, allowedTypes = [ParsedType.string, ParsedType.object], parsedType = getParsedType(argument);
        if (!isOneOf(allowedTypes, parsedType)) {
            this.setIssueForContext(context, {
                code: "invalid_type",
                expected: allowedTypes,
                received: parsedType,
            });
            return INVALID;
        }
        switch (parsedType) {
            case ParsedType.object:
                return this._parseObject(context, argument);
            default:
                return this._parseString(context, argument);
        }
    }
    _parseString(context, argument) {
        // Make sure the character is the correct length
        if (argument.length > this._n) {
            this.setIssueForContext(context, {
                code: "invalid_n_length",
                maximum: this._n,
                received: argument.length,
            });
            return INVALID;
        }
        return OK(new CharacterVaryingClass(argument, this._n));
    }
    _parseObject(context, argument) {
        if (this.isAnyCharacterVarying(argument)) {
            // Make sure the character is the correct length
            if (argument.n > this._n) {
                this.setIssueForContext(context, {
                    code: "invalid_n_length",
                    maximum: this._n,
                    received: argument.n,
                });
                return INVALID;
            }
            return OK(new CharacterVaryingClass(argument.value, this._n));
        }
        const parsedObject = hasKeys(argument, [["value", "string"]]);
        if (parsedObject.success)
            return this._parseString(context, parsedObject.obj.value);
        switch (true) {
            case parsedObject.otherKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "unrecognized_keys",
                    keys: parsedObject.otherKeys,
                });
                break;
            case parsedObject.missingKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "missing_keys",
                    keys: parsedObject.missingKeys,
                });
                break;
            case parsedObject.invalidKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "invalid_key_type",
                    ...parsedObject.invalidKeys[0],
                });
                break;
        }
        return INVALID;
    }
    isCharacterVarying(object, n) {
        if (typeof n === "number")
            return this.setN(n).isCharacterVarying(object);
        return object instanceof CharacterVaryingClass && object.n === this._n;
    }
    isAnyCharacterVarying(object) {
        return object instanceof CharacterVaryingClass;
    }
    setN(n) {
        return new CharacterVaryingConstructorClass(n);
    }
    get n() {
        return this._n;
    }
}
const CharacterVarying = new CharacterVaryingConstructorClass(Number.POSITIVE_INFINITY);
class CharacterVaryingClass extends PGTPBase {
    constructor(_character, _n = Number.POSITIVE_INFINITY) {
        super();
        this._character = _character;
        this._n = _n;
    }
    _equals(input) {
        const parsed = new CharacterVaryingConstructorClass(this._n).safeFrom(...input.data);
        if (parsed.success) {
            return OK({
                equals: parsed.data.toString() === this.toString(),
                data: parsed.data,
            });
        }
        this.setIssueForContext(input, parsed.error.issue);
        return INVALID;
    }
    toString() {
        return this._character;
    }
    toJSON() {
        return {
            value: this._character,
        };
    }
    get characterVarying() {
        return this._character;
    }
    set characterVarying(character) {
        const parsed = new CharacterVaryingConstructorClass(this._n).safeFrom(character);
        if (parsed.success)
            this._character = parsed.data.toString();
        else
            throw parsed.error;
    }
    get value() {
        return this._character;
    }
    set value(character) {
        const parsed = new CharacterVaryingConstructorClass(this._n).safeFrom(character);
        if (parsed.success)
            this._character = parsed.data.toString();
        else
            throw parsed.error;
    }
    get postgres() {
        return this._character;
    }
    set postgres(character) {
        const parsed = new CharacterVaryingConstructorClass(this._n).safeFrom(character);
        if (parsed.success)
            this._character = parsed.data.toString();
        else
            throw parsed.error;
    }
    get n() {
        return this._n;
    }
}
export { CharacterVarying };
//# sourceMappingURL=CharacterVarying.js.map