import { DateTime, Zone } from "luxon";
import type { Offset } from "../../types/Offset.js";
import { OffsetDirection, type OffsetDirectionType } from "../../types/OffsetDirection.js";
import type { SafeEquals } from "../../types/SafeEquals.js";
import type { SafeFrom } from "../../types/SafeFrom.js";
import { Date } from "./Date.js";
import { Time } from "./Time.js";
import { Timestamp } from "./Timestamp.js";
import { TimeTZ } from "./TimeTZ.js";
declare enum TimestampStyle {
    ISO = "ISO",
    ISODate = "ISO-Date",
    ISOTime = "ISO-Time",
    ISODuration = "ISO-Duration",
    ISODurationShort = "ISO-Duration-Short",
    ISODurationBasic = "ISO-Duration-Basic",
    ISODurationExtended = "ISO-Duration-Extended",
    POSIX = "POSIX",
    PostgreSQL = "PostgreSQL",
    PostgreSQLShort = "PostgreSQL-Short",
    SQL = "SQL"
}
type TimestampISOStyles = "ISO" | "ISO-Date" | "ISO-Time";
type TimestampISODurationStyles = "ISO-Duration" | "ISO-Duration-Short" | "ISO-Duration-Basic" | "ISO-Duration-Extended";
type TimestampPOSIXStyles = "POSIX";
type TimestampPostgreSQLStyles = "PostgreSQL" | "PostgreSQL-Short";
type TimestampSQLStyles = "SQL";
type TimestampStyleType = TimestampISOStyles | TimestampISODurationStyles | TimestampPOSIXStyles | TimestampPostgreSQLStyles | TimestampSQLStyles;
interface TimestampTZObject {
    year: number;
    month: number;
    day: number;
    hour: number;
    minute: number;
    second: number;
    offset: Offset;
}
interface TimestampTZ {
    year: number;
    month: number;
    day: number;
    hour: number;
    minute: number;
    second: number;
    offset: Offset;
    value: number;
    postgres: string;
    /**
     * @param style The style to use when converting the timestamp to a string. Defaults to `ISO`.
     * @returns The timestamp as a string.
     * @example
     * const timestamp = TimestampTZ.from("01-01-2023 20:00:23.123456 PST+05:00");
     *
     * timestamp.toString(); // "2023-01-01T20:00:23.123456-13:00"
     * timestamp.toString("ISO"); // "2023-01-01T20:00:23.123456-13:00"
     * timestamp.toString("ISO-Date"); // "2023-01-01"
     * timestamp.toString("ISO-Time"); // "20:00:23.123456-13:00"
     * timestamp.toString("ISO-Duration"); // "P2023Y1M1DT20H0M23.123456S"
     * timestamp.toString("ISO-Duration-Short"); // "P2023Y1M1DT20H23.123456S"
     * timestamp.toString("ISO-Duration-Basic"); // "P20230101T200023.123456S"
     * timestamp.toString("ISO-Duration-Extended"); // "P2023-01-01T20:00:23.123456S"
     * timestamp.toString("POSIX"); // "2023-01-01 20:00:23.123456-13:00"
     * timestamp.toString("PostgreSQL"); // "Sunday January 01 2023 20:00:23.123456 -13:00"
     * timestamp.toString("PostgreSQL-Short"); // "Sun Jan 01 2023 20:00:23.123456 -13:00"
     * timestamp.toString("SQL"); // "2023-01 01 20:00:23.123456-13:00"
     */
    toString(style?: TimestampStyle | TimestampStyleType): string;
    /**
     * @returns The timestamp as a unix timestamp.
     */
    toNumber(): number;
    toJSON(): TimestampTZObject;
    toDate(): Date;
    toTime(): Time;
    toTimeTZ(): TimeTZ;
    toTimestamp(): Timestamp;
    /**
     * @param zone The zone to convert the timestamp to. Defaults to 'local'.
     */
    toDateTime(zone?: string | Zone | undefined): DateTime;
    /**
     * @param zone The zone to convert the timestamp to. Defaults to 'local'.
     */
    toJSDate(zone?: string | Zone | undefined): globalThis.Date;
    equals(string: string): boolean;
    equals(unixTimestamp: number): boolean;
    equals(year: number, month: number, day: number, hour: number, minute: number, second: number, offsetHour: number, offsetMinute: number, offsetDirection: OffsetDirection | OffsetDirectionType): boolean;
    equals(timestamptz: TimestampTZ | globalThis.Date | DateTime): boolean;
    equals(object: TimestampTZObject): boolean;
    safeEquals(string: string): SafeEquals<TimestampTZ>;
    safeEquals(unixTimestamp: number): SafeEquals<TimestampTZ>;
    safeEquals(year: number, month: number, day: number, hour: number, minute: number, second: number, offsetHour: number, offsetMinute: number, offsetDirection: OffsetDirection | OffsetDirectionType): SafeEquals<TimestampTZ>;
    safeEquals(timestamptz: TimestampTZ | globalThis.Date | DateTime): SafeEquals<TimestampTZ>;
    safeEquals(object: TimestampTZObject): SafeEquals<TimestampTZ>;
}
interface TimestampTZConstructor {
    from(string: string): TimestampTZ;
    from(unixTimestamp: number): TimestampTZ;
    from(year: number, month: number, day: number, hour: number, minute: number, second: number, offsetHour: number, offsetMinute: number, offsetDirection: OffsetDirection | OffsetDirectionType): TimestampTZ;
    from(timestamptz: TimestampTZ | globalThis.Date | DateTime): TimestampTZ;
    from(object: TimestampTZObject): TimestampTZ;
    safeFrom(string: string): SafeFrom<TimestampTZ>;
    safeFrom(unixTimestamp: number): SafeFrom<TimestampTZ>;
    safeFrom(year: number, month: number, day: number, hour: number, minute: number, second: number, offsetHour: number, offsetMinute: number, offsetDirection: OffsetDirection | OffsetDirectionType): SafeFrom<TimestampTZ>;
    safeFrom(timestamptz: TimestampTZ | globalThis.Date | DateTime): SafeFrom<TimestampTZ>;
    safeFrom(object: TimestampTZObject): SafeFrom<TimestampTZ>;
    /**
     * Returns `true` if `object` is a `TimestampTZ`, `false` otherwise.
     */
    isTimestampTZ(object: any): object is TimestampTZ;
}
declare const TimestampTZ: TimestampTZConstructor;
export { TimestampStyle, TimestampStyleType, TimestampTZ, TimestampTZConstructor, TimestampTZObject };
