import { getParsedType, hasKeys, INVALID, isOneOf, OK, ParsedType } from "@postgresql-typed/util";
import { PGTPBase } from "../../util/PGTPBase.js";
import { PGTPConstructorBase } from "../../util/PGTPConstructorBase.js";
import { throwPGTPError } from "../../util/throwPGTPError.js";
class PointConstructorClass extends PGTPConstructorBase {
    constructor() {
        super();
    }
    _parse(context) {
        const [argument, ...otherArguments] = context.data, allowedTypes = [ParsedType.number, ParsedType.nan, ParsedType.string, ParsedType.object], parsedType = getParsedType(argument);
        if (parsedType !== ParsedType.number && parsedType !== ParsedType.nan && context.data.length !== 1) {
            this.setIssueForContext(context, context.data.length > 1
                ? {
                    code: "too_big",
                    type: "arguments",
                    maximum: 1,
                    exact: true,
                }
                : {
                    code: "too_small",
                    type: "arguments",
                    minimum: 1,
                    exact: true,
                });
            return INVALID;
        }
        if (!isOneOf(allowedTypes, parsedType)) {
            this.setIssueForContext(context, {
                code: "invalid_type",
                expected: allowedTypes,
                received: parsedType,
            });
            return INVALID;
        }
        switch (parsedType) {
            case "string":
                return this._parseString(context, argument);
            case "number":
            case "nan":
                return this._parseNumber(context, argument, otherArguments);
            default:
                return this._parseObject(context, argument);
        }
    }
    _parseString(context, argument) {
        // Remove all whitespace
        argument = argument.replaceAll(/\s/g, "");
        if (/^\((?:-?\d+(\.\d+)?|NaN),(?:-?\d+(\.\d+)?|NaN)\)$/.test(argument)) {
            const [x, y] = argument
                .slice(1, -1)
                .split(",")
                .map(c => Number.parseFloat(c));
            return OK(new PointClass(x, y));
        }
        this.setIssueForContext(context, {
            code: "invalid_string",
            received: argument,
            expected: "LIKE (x,y)",
        });
        return INVALID;
    }
    _parseNumber(context, argument, otherArguments) {
        const totalLength = otherArguments.length + 1;
        if (totalLength !== 2) {
            this.setIssueForContext(context, totalLength > 2
                ? {
                    code: "too_big",
                    type: "arguments",
                    maximum: 2,
                    exact: true,
                }
                : {
                    code: "too_small",
                    type: "arguments",
                    minimum: 2,
                    exact: true,
                });
            return INVALID;
        }
        for (const otherArgument of otherArguments) {
            const allowedTypes = [ParsedType.number, ParsedType.nan], parsedType = getParsedType(otherArgument);
            if (!isOneOf(allowedTypes, parsedType)) {
                this.setIssueForContext(context, {
                    code: "invalid_type",
                    expected: allowedTypes,
                    received: parsedType,
                });
                return INVALID;
            }
        }
        const [x, y] = [argument, ...otherArguments];
        return OK(new PointClass(x, y));
    }
    _parseObject(context, argument) {
        if (this.isPoint(argument))
            return OK(new PointClass(argument.x, argument.y));
        const parsedObject = hasKeys(argument, [
            ["x", ["number", "nan"]],
            ["y", ["number", "nan"]],
        ]);
        if (parsedObject.success)
            return OK(new PointClass(parsedObject.obj.x, parsedObject.obj.y));
        switch (true) {
            case parsedObject.otherKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "unrecognized_keys",
                    keys: parsedObject.otherKeys,
                });
                break;
            case parsedObject.missingKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "missing_keys",
                    keys: parsedObject.missingKeys,
                });
                break;
            case parsedObject.invalidKeys.length > 0:
                this.setIssueForContext(context, {
                    code: "invalid_key_type",
                    ...parsedObject.invalidKeys[0],
                });
                break;
        }
        return INVALID;
    }
    isPoint(object) {
        return object instanceof PointClass;
    }
}
const Point = new PointConstructorClass();
class PointClass extends PGTPBase {
    constructor(_x, _y) {
        super();
        this._x = _x;
        this._y = _y;
    }
    _equals(context) {
        //@ts-expect-error - _equals receives the same context as _parse
        const parsed = Point.safeFrom(...context.data);
        if (parsed.success) {
            return OK({
                equals: parsed.data.toString() === this.toString(),
                data: parsed.data,
            });
        }
        this.setIssueForContext(context, parsed.error.issue);
        return INVALID;
    }
    toString() {
        return `(${this._x},${this._y})`;
    }
    toJSON() {
        return {
            x: this._x,
            y: this._y,
        };
    }
    get x() {
        return this._x;
    }
    set x(x) {
        const parsedType = getParsedType(x);
        if (parsedType !== ParsedType.number && parsedType !== ParsedType.nan) {
            throwPGTPError({
                code: "invalid_type",
                expected: [ParsedType.number],
                received: parsedType,
            });
        }
        this._x = x;
    }
    get y() {
        return this._y;
    }
    set y(y) {
        const parsedType = getParsedType(y);
        if (parsedType !== ParsedType.number && parsedType !== ParsedType.nan) {
            throwPGTPError({
                code: "invalid_type",
                expected: [ParsedType.number],
                received: parsedType,
            });
        }
        this._y = y;
    }
    get value() {
        return this.toString();
    }
    set value(point) {
        const parsed = Point.safeFrom(point);
        if (parsed.success) {
            this._x = parsed.data.x;
            this._y = parsed.data.y;
        }
        else
            throw parsed.error;
    }
    get postgres() {
        return this.toString();
    }
    set postgres(point) {
        const parsed = Point.safeFrom(point);
        if (parsed.success) {
            this._x = parsed.data.x;
            this._y = parsed.data.y;
        }
        else
            throw parsed.error;
    }
}
export { Point };
//# sourceMappingURL=Point.js.map