export declare const REGEXES: {
    /**
     * Traditional PostgreSQL interval format
     * @example "1 millennium 2 centuries 3 decades 4 year 5 months 6 days 7 hours 8 minutes 9 seconds 10 milliseconds 11 microseconds"
     */
    TraditionalPostgreSQLInterval: {
        match: (string: string) => {
            millennium: string;
            century: string;
            decade: string;
            year: string;
            month: string;
            week: string;
            day: string;
            hour: string;
            minute: string;
            second: string;
            millisecond: string;
            microsecond: string;
        } | null;
    };
    /**
     * Traditional PostgreSQL interval format with time
     * @exmaple "1 millennium 2 centuries 3 decades 4 year 5 months 6 days 7:08:09"
     */
    TraditionalPostgreSQLTimeInterval: {
        match: (string: string) => {
            millennium: string;
            century: string;
            decade: string;
            year: string;
            month: string;
            week: string;
            day: string;
            hour: string;
            minute: string;
            second: string;
        } | null;
    };
    /**
     * ISO 8601 Durations “format with designators”
     * @example "P1Y2M3W4DT5H6M7S"
     * @see https://en.wikipedia.org/wiki/ISO_8601#Durations
     */
    ISO8601DurationsDesignators: {
        match: (string: string) => {
            year: string;
            month: string;
            week: string;
            day: string;
            hour: string;
            minute: string;
            second: string;
        } | null;
    };
    /**
     * ISO 8601 Durations “basic format”
     * @example "PYYYYMMDDThhmmss"
     * @see https://en.wikipedia.org/wiki/ISO_8601#Durations
     */
    ISO8601DurationsBasic: {
        match: (string: string) => {
            year: string;
            month: string;
            day: string;
            hour: string;
            minute: string;
            second: string;
        } | null;
    };
    /**
     * ISO 8601 Durations “extended format”
     * @example "PYYYY-MM-DDThh:mm:ss"
     * @see https://en.wikipedia.org/wiki/ISO_8601#Durations
     */
    ISO8601DurationsExtended: {
        match: (string: string) => {
            year: string;
            month: string;
            day: string;
            hour: string;
            minute: string;
            second: string;
        } | null;
    };
    /**
     * SQL standard interval format "year to second"
     * @example "YYYY-MM DD HH:MM:SS"
     */
    SQLYearToSecond: {
        match: (string: string) => {
            year: string;
            month: string;
            day: string;
            hour: string;
            minute: string;
            second: string;
        } | null;
    };
    /**
     * SQL standard interval format "year to month"
     * @example "YYYY-MM"
     */
    SQLYearToMonth: {
        match: (string: string) => {
            year: string;
            month: string;
        } | null;
    };
    /**
     * SQL standard interval format "day to second"
     * @example "DD hh:mm:ss"
     */
    SQLDayToSecond: {
        match: (string: string) => {
            day: string;
            hour: string;
            minute: string;
            second: string;
        } | null;
    };
    /**
     * SQL standard interval format "hour to second"
     * @example "hh:mm:ss"
     */
    SQLHourToSecond: {
        match: (string: string) => {
            hour: string;
            minute: string;
            second: string;
        } | null;
    };
    SQLMinuteToSecond: {
        match: (string: string) => {
            hour: string;
            minute: string;
        } | null;
    };
    /**
     * SQL standard interval format "second"
     * @example "ss"
     */
    SQLSecond: {
        match: (string: string) => {
            second: string;
        } | null;
    };
    /**
     * ISO 8601 Dates (The dashes may be replaced by slashes or be omitted entirely.) (The length of the numbers are checked)
     * @example "YYYY-MM-DD" or "DD-MM-YYYY" or "MM-DD-YYYY" or "YY-MM-DD" or "DD-MM-YY" or "MM-DD-YY
     * @see https://en.wikipedia.org/wiki/ISO_8601#Dates
     */
    ISO8601Date: {
        match: (string: string) => {
            year: string;
            month: string;
            day: string;
        } | null;
    };
    /**
     * ISO 8601 Times (With optional timezone) (The dashes may be replaced by slashes or be omitted entirely.) (The length of the numbers are checked, except for seconds which can be a decimal)
     * @example "hh:mm:ss" or "hh:mm:ss±hh:mm" or "hh:mm:ss±hh" or "hh:mm:ssZ"
     * @see https://en.wikipedia.org/wiki/ISO_8601#Times
     */
    ISO8601Time: {
        match: (string: string) => {
            hour: string;
            minute: string;
            second?: string | undefined;
            ampm?: string | undefined;
            timezoneSign?: string | undefined;
            timezoneHour?: string | undefined;
            timezoneMinute?: string | undefined;
        } | null;
    };
    /**
     * ISO 8601 DateTimes (The ISO 8601 date and time formats can be combined into a single expression)
     * @example "YYYY-MM-DDThh:mm:ss" or "YYYY-MM-DDThh:mm:ss±hh:mm" or "YYYY-MM-DDThh:mm:ss±hh" or "YYYY-MM-DDThh:mm:ssZ" or "YYYY-MM-DD hh:mm:ss" or "YYYY-MM-DD hh:mm:ss±hh:mm" or "YYYY-MM-DD hh:mm:ss±hh" or "YYYY-MM-DD hh:mm:ss"
     * @see https://en.wikipedia.org/wiki/ISO_8601#Combined_date_and_time_representations
     */
    ISO8601DateTime: {
        match: (string: string) => {
            year: string;
            month: string;
            day: string;
            hour: string;
            minute: string;
            second: string;
            timezoneSign?: string | undefined;
            timezoneHour?: string | undefined;
            timezoneMinute?: string | undefined;
        } | null;
    };
    /**
     * POSIX DateTimes (With optional timezone) (The length of the numbers are checked)
     * @example "YYYY-MM-DD hh:mm:ss <timezone>±hh:mm" or "YYYY-MM-DD hh:mm:ss <timezone>±hh" or "YYYY-MM-DD hh:mm:ss <timezone>" or "YYYY-MM-DD hh:mm:ss"
     * Timezone can be any string like GMT, UTC, EST, CST, MST, PST, etc. (case insensitive)
     * They can also be like Europe/Paris, America/New_York, etc. (case insensitive)
     */
    POSIXDateTime: {
        match: (string: string) => {
            year: string;
            month: string;
            day: string;
            hour: string;
            minute: string;
            second?: string | undefined;
            ampm?: string | undefined;
            timezone?: string | undefined;
            timezoneSign?: string | undefined;
            timezoneHour?: string | undefined;
            timezoneMinute?: string | undefined;
        } | null;
    };
    /**
     * POSIX DateTimes (With optional timezone) (The length of the numbers are checked)
     * @example "hh:mm:ss <timezone>±hh:mm" or "hh:mm:ss <timezone>±hh" or "hh:mm:ss <timezone>" or "hh:mm"
     * Timezone can be any string like GMT, UTC, EST, CST, MST, PST, etc. (case insensitive)
     * They can also be like Europe/Paris, America/New_York, etc. (case insensitive)
     */
    POSIXTime: {
        match: (string: string) => {
            hour: string;
            minute: string;
            second?: string | undefined;
            ampm?: string | undefined;
            timezone?: string | undefined;
            timezoneSign?: string | undefined;
            timezoneHour?: string | undefined;
            timezoneMinute?: string | undefined;
        } | null;
    };
    /**
     * PostgreSQL DateTimes (With optional day of week and optional timezone)
     * @example "Mon Feb 10 15:30:00 2020 PST" or "Feb 10 15:30:00 2020" or "Mon Feb 10 2020 15:30:00 PST" or "Feb 10 2020 15:30:00"
     * Timezone can be any string like GMT, UTC, EST, CST, MST, PST, etc. (case insensitive)
     * They can also be like Europe/Paris, America/New_York, etc. (case insensitive)
     *
     * The day of week is optional and can be any string like Mon, Tue, Wed, Thu, Fri, Sat, Sun (case insensitive)
     * They can also be like Monday, Tuesday, Wednesday, Thursday, Friday, Saturday, Sunday (case insensitive)
     *
     * The month can be any string like Jan, Feb, Mar, Apr, May, Jun, Jul, Aug, Sep, Oct, Nov, Dec (case insensitive)
     * They can also be like January, February, March, April, May, June, July, August, September, October, November, December (case insensitive)
     */
    PostgreSQLDateTime: {
        match: (string: string) => {
            dayOfWeek?: string | undefined;
            year: string;
            month: string;
            day: string;
            hour: string;
            minute: string;
            second: string;
            ampm?: string | undefined;
            timezone?: string | undefined;
            timezoneSign?: string | undefined;
            timezoneHour?: string | undefined;
            timezoneMinute?: string | undefined;
        } | null;
    };
};
